log using Analysis.log, replace
/*==============================================================================

Public Replication File for:

Alan S. Gerber, Gregory A. Huber, and Albert H. Fang

"Do Subtle Linguistic Interventions Priming a Social Identity
as a Voter Have Outsized Effets on Voter Turnout? Evidence
From a New Replication Experiment"

Political Psychology. doi: 10.1111/pops.12446

Original version: 29 September 2017
Corrected version: 10 March 2023

****
Please note that is a corrected file. It corrects the difference in proportions result reported in Table 3.
Those estimates, but not the regression estimates or any other number in the table, had their signs reversed.
Please see CorrectionNote.txt for additional details.
****

==============================================================================*/

/*------------------------------------------------------------------------------
 Load packages, prepare data
------------------------------------------------------------------------------*/

clear all
set more off, permanently

* Install packages (outreg2 and outsum)
ssc install outreg2
net install outsum

* Read in data
use PublicReplicationData.dta, clear


/*============================================================================*/
/*============================================================================*/
/*====================== TABLES AND FIGURES IN MAIN TEXT =====================*/
/*============================================================================*/
/*============================================================================*/

/*------------------------------------------------------------------------------
 Table 3 - Estimated Effect of Noun Wording (versus verb wording)
  on Turnout in the 2015 General Election
  
 (ALSO: Appendix Table A4 - Full Regression Estimates)
------------------------------------------------------------------------------*/

/*----- Columns 1-2: Estimate difference in proportions -----*/

capture erase "Table3_DifferenceInProportions.dta"
tempname tempfile
postfile `tempfile' str10 dv str15 sample estimate se p using "Table3_DifferenceInProportions.dta"

foreach cond in "" "if ssi==0" "if ssi==1" "if d_state1==1" "if d_state2==1" "if d_state3==1" "if d_state4==1" {
	prtest V15 `cond' , by(treat_noun)
	* This line was  corrected in March 2023. The difference estimate had the sign reversed.
	local diff = r(P_2) - r(P_1)
	local se = `diff' / r(z)
	local p = 2*( normprob(-abs(r(z))))
	post `tempfile' ("V15") ("`cond'") (`diff') (`se') (`p')
}

postclose `tempfile'

preserve
use "Table3_DifferenceInProportions.dta", clear
outsheet using "Table3_DifferenceInProportions.csv" , comma replace
restore
erase "Table3_DifferenceInProportions.dta"

/*----- Columns 3-7: Regression estimates (and Appendix Table A4) -----*/

* Define past vote covariates as global macro
foreach vvar in V_G04 V_G06 V_G08 V_G10 V_G12 V_G14 V_P04 V_P06 V_P08 V_P10 V_P12 V_P14 V_P15 V_PP04 V_PP08 V_PP12 {
	tab `vvar' ssi, m
}
global pastvote V_G04 V_G06 V_G08 V_G10 V_G12 V_G14 V_P04 V_P06 V_P08 V_P10 V_P12 V_P14 V_P15 V_PP04 V_PP08 V_PP12

* Create state-by-covariate interactions
foreach st in 2 3 4 {
	foreach v in d_date2 d_date3 d_date4 d_date5 d_date6 d_date7 d_date8 d_gend2 d_gend3 d_race1 d_race2 d_race3 daysbefore V_G04 V_G06 V_G08 V_G10 V_G12 V_G14 V_P04 V_P06 V_P08 V_P10 V_P12 V_P14 V_P15 V_PP04 V_PP08 V_PP12 {
		gen Z_dstate`st'_`v' = d_state`st' * `v' 
		qui sum Z_dstate`st'_`v'
		if (r(sd) == 0 | r(sd) == .) {
			drop Z_dstate`st'_`v'
		}
	}
}


capture erase "Table3_RegressionEstimates.dta"
tempname tempfile
postfile `tempfile' str10 dv str15 sample str1 ipw b_noun se_noun pval lci_noun uci_noun c_mean c_se c_N t_N using "Table3_RegressionEstimates.dta"

foreach Y in V15 {
	foreach cond in "" "if ssi==0" "if ssi==1" "if d_state1==1" "if d_state2==1" "if d_state3==1" "if d_state4==1" {

		* Make column labels
		if ("`cond'" == ""){
			local coltag = "Entire Sample"
		}
		else if ("`cond'" == "if ssi==0"){
			local coltag = "YouGov Only"
		}
		else if ("`cond'" == "if ssi==1"){
			local coltag = "SSI Only"
		}
		else if ("`cond'" == "if d_state1==1"){
			local coltag = "KY Only"
		}
		else if ("`cond'" == "if d_state2==1"){
			local coltag = "LA Only"
		}
		else if ("`cond'" == "if d_state3==1"){
			local coltag = "MS Only"
		}
		else if ("`cond'" == "if d_state4==1"){
			local coltag = "TX Only"
		}

		* Weighted
		reg `Y' treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote Z_* `cond' [aweight=ipw]
		local lci_noun = _b[treat_noun] - invttail( e(df_r), 0.025 )*_se[treat_noun]
		local uci_noun = _b[treat_noun] + invttail( e(df_r), 0.025 )*_se[treat_noun]
		local pval = 2*ttail(e(df_r),abs( _b[treat_noun]/_se[treat_noun] ))
		qui sum `Y' [aweight=ipw] if treat_noun == 0 & e(sample)
		local c_mean = r(mean)
		local c_se = r(sd) / sqrt(r(N))
		local c_N = r(N)
		qui sum `Y' [aweight=ipw] if treat_noun == 1 & e(sample)
		local t_N = r(N)
		local ipw = "Y"
		post `tempfile' ("`Y'") ("`cond'") ("`ipw'") (_b[treat_noun]) (_se[treat_noun]) (`pval') (`lci_noun') (`uci_noun') (`c_mean') (`c_se') (`c_N') (`t_N')
		if ("`cond'" == "") {
			outreg2 using "TableA4_FullRegressionTable.tex", ctitle("`coltag'") se bracket rdec(3) label tex(frag) ///
				keep(treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
				addstat("Verb Group Mean Outcome", `c_mean') ///
				addtext("State-By-Covariate Interactions?", Y, "Weighted?", Y) replace
		}
		else {
			outreg2 using "TableA4_FullRegressionTable.tex", ctitle("`coltag'") se bracket rdec(2) label tex(frag) ///
				keep(treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
				addstat("Verb Group Mean Outcome", `c_mean') ///
				addtext("State-By-Covariate Interactions?", Y, "Weighted?", Y) append
		}


		* Unweighted
		reg `Y' treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote Z_* `cond'
		local lci_noun = _b[treat_noun] - invttail( e(df_r), 0.025 )*_se[treat_noun]
		local uci_noun = _b[treat_noun] + invttail( e(df_r), 0.025 )*_se[treat_noun]
		local pval = 2*ttail(e(df_r),abs( _b[treat_noun]/_se[treat_noun] ))
		qui sum `Y' if treat_noun == 0 & e(sample)
		local c_mean = r(mean)
		local c_se = r(sd) / sqrt(r(N))
		local c_N = r(N)
		qui sum `Y' if treat_noun == 1 & e(sample)
		local t_N = r(N)
		local ipw = "N"
		*Note we still save full regression results for unweighted analysis; they just aren't reported in Table 3 so not posted to tempfile
		*post `tempfile' ("`Y'") ("`cond'") ("`ipw'") (_b[treat_noun]) (_se[treat_noun]) (`pval') (`lci_noun') (`uci_noun') (`c_mean') (`c_se') (`c_N') (`t_N')
		outreg2 using "TableA4_FullRegressionTable.tex", ctitle("`coltag'") se bracket rdec(2) label tex(frag) ///
			keep(treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
			addstat("Verb Group Mean Outcome", `c_mean') ///
			addtext("State-By-Covariate Interactions?", Y, "Weighted?", N) append

	}
}

postclose `tempfile'


preserve
use "Table3_RegressionEstimates.dta", clear
outsheet using "Table3_RegressionEstimates.csv", comma replace
restore
erase "Table3_RegressionEstimates.dta"

/*------------------------------------------------------------------------------
 Figure 1: Estimates Across Studies
	See "Figure1.R" for replication code
------------------------------------------------------------------------------*/



/*============================================================================*/
/*============================================================================*/
/*====================== APPENDIX TABLES             =========================*/
/*======================    (excl. Appendix Table A4 =========================*/
/*============================================================================*/
/*============================================================================*/


/*------------------------------------------------------------------------------
 Table A1: Randomization Checks
------------------------------------------------------------------------------*/

* YouGov sample
reg treat_noun d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 $pastvote daysbefore Z_* if ssi==0
testparm *
local Fstat = round(r(F), .01)
local pval = round(r(p), .01)
outreg2 using "TableA1_RandomizationChecks.tex", ctitle("YouGov Subsample") se bracket rdec(3) label tex(frag) ///
	keep(d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
	addstat("F-statistic", `Fstat', "F-test p-value", `pval') replace

* SSI sample
reg treat_noun d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 $pastvote daysbefore Z_* if ssi==1
testparm *
local Fstat = round(r(F), .01)
local pval = round(r(p), .01)
outreg2 using "TableA1_RandomizationChecks.tex", ctitle("SSI Subsample") se bracket rdec(3) label tex(frag) ///
	keep(d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote ) ///
	addstat("F-statistic", `Fstat', "F-test p-value", `pval') append

/*------------------------------------------------------------------------------
 Table A2: Balance Table - Unweighted Summary Statistics by Arm
------------------------------------------------------------------------------*/

foreach cond in "if ssi==0 & treat_noun==0" "if ssi==0 & treat_noun==1" "if ssi==0" /// 
	"if ssi==1 & treat_noun==0" "if ssi==1 & treat_noun==1" "if ssi==1" ///
	"if treat_noun==0" "if treat_noun==1" "" {
	
	if ( "`cond'"  == "if ssi==0 & treat_noun==0" ) {
		local collabel = "YouGov Verb"
	}
	if ( "`cond'"  == "if ssi==0 & treat_noun==1" ) {
		local collabel = "YouGov Noun"
	}
	if ( "`cond'"  == "if ssi==0" ) {
		local collabel = "YouGov Total"
	}
	if ( "`cond'"  == "if ssi==1 & treat_noun==0" ) {
		local collabel = "SSI Verb"
	}
	if ( "`cond'"  == "if ssi==1 & treat_noun==1" ) {
		local collabel = "SSI Noun"
	}
	if ( "`cond'"  == "if ssi==1" ) {
		local collabel = "SSI Total"
	}
	if ( "`cond'"  == "if treat_noun==0" ) {
		local collabel = "Pooled Verb"
	}
	if ( "`cond'"  == "if treat_noun==1" ) {
		local collabel = "Pooled Noun"
	}
	if ( "`cond'"  == "" ) {
		local collabel = "Pooled Total"
	}
		
	if ( "`cond'" == "if ssi==0 & treat_noun==0" ) {
		outsum d_state1-d_state4 d_date1-d_date8 d_gend1-d_gend3 d_race1-d_race4 daysbefore $pastvote `cond' using "TableA2_BalanceTable_Unweighted.out" , replace ///
		 ctitle("`collabel'") bracket
	}
	else {
		outsum d_state1-d_state4 d_date1-d_date8 d_gend1-d_gend3 d_race1-d_race4 daysbefore $pastvote `cond' using "TableA2_BalanceTable_Unweighted.out" , append ///
		 ctitle("`collabel'") bracket
	}
	
	}
	
/*------------------------------------------------------------------------------
 Table A3: Balance Table - Weighted Summary Statistics by Arm
------------------------------------------------------------------------------*/

foreach cond in "if ssi==0 & treat_noun==0" "if ssi==0 & treat_noun==1" "if ssi==0" /// 
	"if ssi==1 & treat_noun==0" "if ssi==1 & treat_noun==1" "if ssi==1" ///
	"if treat_noun==0" "if treat_noun==1" "" {
	
	if ( "`cond'"  == "if ssi==0 & treat_noun==0" ) {
		local collabel = "YouGov Verb"
	}
	if ( "`cond'"  == "if ssi==0 & treat_noun==1" ) {
		local collabel = "YouGov Noun"
	}
	if ( "`cond'"  == "if ssi==0" ) {
		local collabel = "YouGov Total"
	}
	if ( "`cond'"  == "if ssi==1 & treat_noun==0" ) {
		local collabel = "SSI Verb"
	}
	if ( "`cond'"  == "if ssi==1 & treat_noun==1" ) {
		local collabel = "SSI Noun"
	}
	if ( "`cond'"  == "if ssi==1" ) {
		local collabel = "SSI Total"
	}
	if ( "`cond'"  == "if treat_noun==0" ) {
		local collabel = "Pooled Verb"
	}
	if ( "`cond'"  == "if treat_noun==1" ) {
		local collabel = "Pooled Noun"
	}
	if ( "`cond'"  == "" ) {
		local collabel = "Pooled Total"
	}
		
	if ( "`cond'" == "if ssi==0 & treat_noun==0" ) {
		outsum d_state1-d_state4 d_date1-d_date8 d_gend1-d_gend3 d_race1-d_race4 daysbefore $pastvote [aweight=ipw] `cond' using "TableA3_BalanceTable_Weighted.out" , replace ///
		 ctitle("`collabel'") bracket
	}
	else {
		outsum d_state1-d_state4 d_date1-d_date8 d_gend1-d_gend3 d_race1-d_race4 daysbefore $pastvote [aweight=ipw] `cond' using "TableA3_BalanceTable_Weighted.out" , append ///
		 ctitle("`collabel'") bracket
	}
	
}

/*------------------------------------------------------------------------------
 Table A5: Robustness Check - Subjects Entering Exp On/Day Before Elec Day
------------------------------------------------------------------------------*/

* Re-load data
use PublicReplicationData.dta, clear

* Keep only subjects who entered study on or day before election
keep if inlist(daysbefore, 0, 1)

* Drop IPW variable 
drop ipw 

* Re-calculate IPWs
foreach s in 0 1 {
	preserve
	contract treat if ssi==`s', freq(freq) percent(pct)
	list, t noobs clean
	gen ipw`s' = 1/(pct/100)
	list, t noobs clean
	keep treat ipw`s'
	gen ssi = `s'
	save "temp_ipw_`s'.dta", replace
	restore	
}

merge m:1 ssi treat using "temp_ipw_0.dta"
tab treat ipw0 if ssi==0, m
tab treat ipw0 if ssi==1, m
drop _merge
erase "temp_ipw_0.dta"

merge m:1 ssi treat using "temp_ipw_1.dta"
tab treat ipw1 if ssi==0, m
tab treat ipw1 if ssi==1, m
drop _merge
erase "temp_ipw_1.dta"

gen ipw = ipw1
replace ipw = ipw0 if ssi==0
tab ssi ipw, m
drop ipw1 ipw0

* Re-create state-by-covariate interations
foreach st in 2 3 4 {
	foreach v in d_date2 d_date3 d_date4 d_date5 d_date6 d_date7 d_date8 d_gend2 d_gend3 d_race1 d_race2 d_race3 daysbefore V_G04 V_G06 V_G08 V_G10 V_G12 V_G14 V_P04 V_P06 V_P08 V_P10 V_P12 V_P14 V_P15 V_PP04 V_PP08 V_PP12 {
		gen Z_dstate`st'_`v' = d_state`st' * `v' 
		qui sum Z_dstate`st'_`v'
		if (r(sd) == 0 | r(sd) == .) {
			drop Z_dstate`st'_`v'
		}
	}
}

* Estimate models
foreach Y in V15 {
	foreach cond in "" "if ssi==0" "if ssi==1" "if d_state1==1" "if d_state2==1" "if d_state3==1" "if d_state4==1" {

	* Make column labels
	if ("`cond'" == ""){
		local coltag = "Entire Sample"
	}
	else if ("`cond'" == "if ssi==0"){
		local coltag = "YouGov Only"
	}
	else if ("`cond'" == "if ssi==1"){
		local coltag = "SSI Only"
	}
	else if ("`cond'" == "if d_state1==1"){
		local coltag = "KY Only"
	}
	else if ("`cond'" == "if d_state2==1"){
		local coltag = "LA Only"
	}
	else if ("`cond'" == "if d_state3==1"){
		local coltag = "MS Only"
	}
	else if ("`cond'" == "if d_state4==1"){
		local coltag = "TX Only"
	}

	* Weighted
	reg `Y' treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote Z_* `cond' [aweight=ipw]
	local lci_noun = _b[treat_noun] - invttail( e(df_r), 0.025 )*_se[treat_noun]
	local uci_noun = _b[treat_noun] + invttail( e(df_r), 0.025 )*_se[treat_noun]
	local pval = 2*ttail(e(df_r),abs( _b[treat_noun]/_se[treat_noun] ))
	qui sum `Y' [aweight=ipw] if treat_noun == 0 & e(sample)
	local c_mean = r(mean)
	local c_se = r(sd) / sqrt(r(N))
	local c_N = r(N)
	qui sum `Y' [aweight=ipw] if treat_noun == 1 & e(sample)
	local t_N = r(N)
	local ipw = "Y"

	if ("`cond'" == "") {
		outreg2 using "TableA5_Robustness_OnBeforeED.tex", ctitle("`coltag'") se bracket rdec(3) label tex(frag) ///
			keep(treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
			addstat("Verb Group Mean Outcome", `c_mean') ///
			addtext("State-By-Covariate Interactions?", Y, "Weighted?", Y) replace
	}
	else {
		outreg2 using "TableA5_Robustness_OnBeforeED.tex", ctitle("`coltag'") se bracket rdec(2) label tex(frag) ///
			keep(treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
			addstat("Verb Group Mean Outcome", `c_mean') ///
			addtext("State-By-Covariate Interactions?", Y, "Weighted?", Y) append
	}

	* Unweighted
	reg `Y' treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote Z_* `cond'
	local lci_noun = _b[treat_noun] - invttail( e(df_r), 0.025 )*_se[treat_noun]
	local uci_noun = _b[treat_noun] + invttail( e(df_r), 0.025 )*_se[treat_noun]
	local pval = 2*ttail(e(df_r),abs( _b[treat_noun]/_se[treat_noun] ))
	qui sum `Y' if treat_noun == 0 & e(sample)
	local c_mean = r(mean)
	local c_se = r(sd) / sqrt(r(N))
	local c_N = r(N)
	qui sum `Y' if treat_noun == 1 & e(sample)
	local t_N = r(N)
	local ipw = "N"

	outreg2 using "TableA5_Robustness_OnBeforeED.tex", ctitle("`coltag'") se bracket rdec(2) label tex(frag) ///
		keep(treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
		addstat("Verb Group Mean Outcome", `c_mean') ///
		addtext("State-By-Covariate Interactions?", Y, "Weighted?", N) append
		
	}
}




/*------------------------------------------------------------------------------
 Table A6: Robustness Check - Subjects in KY, LA only
------------------------------------------------------------------------------*/

* Re-load data
use PublicReplicationData.dta, clear

* Keep only subjects who are in KY, LA only
keep if inlist(state, "KY", "LA")

* Drop IPW variable 
drop ipw 

* Recalculate IPWs

foreach s in 0 1 {
	preserve
	contract treat if ssi==`s', freq(freq) percent(pct)
	list, t noobs clean
	gen ipw`s' = 1/(pct/100)
	list, t noobs clean
	keep treat ipw`s'
	gen ssi = `s'
	save "temp_ipw_`s'.dta", replace
	restore	
}

merge m:1 ssi treat using "temp_ipw_0.dta"
tab treat ipw0 if ssi==0, m
tab treat ipw0 if ssi==1, m
drop _merge
erase "temp_ipw_0.dta"

merge m:1 ssi treat using "temp_ipw_1.dta"
tab treat ipw1 if ssi==0, m
tab treat ipw1 if ssi==1, m
drop _merge
erase "temp_ipw_1.dta"

gen ipw = ipw1
replace ipw = ipw0 if ssi==0
tab ssi ipw, m
drop ipw1 ipw0


* Create state-by-covariate interactions
foreach st in 2 3 4 {
	foreach v in d_date2 d_date3 d_date4 d_date5 d_date6 d_date7 d_date8 d_gend2 d_gend3 d_race1 d_race2 d_race3 daysbefore V_G04 V_G06 V_G08 V_G10 V_G12 V_G14 V_P04 V_P06 V_P08 V_P10 V_P12 V_P14 V_P15 V_PP04 V_PP08 V_PP12 {
			gen Z_dstate`st'_`v' = d_state`st' * `v' 
			qui sum Z_dstate`st'_`v'
			if (r(sd) == 0 | r(sd) == .) {
				drop Z_dstate`st'_`v'
			}
	}
}

* Estimate models
foreach Y in V15 {
	foreach cond in "" "if ssi==0" "if ssi==1" {

		* Make column labels
		if ("`cond'" == ""){
			local coltag = "Entire Sample"
		}
		else if ("`cond'" == "if ssi==0"){
			local coltag = "YouGov Only"
		}
		else if ("`cond'" == "if ssi==1"){
			local coltag = "SSI Only"
		}
		else if ("`cond'" == "if d_state1==1"){
			local coltag = "KY Only"
		}
		else if ("`cond'" == "if d_state2==1"){
			local coltag = "LA Only"
		}
		else if ("`cond'" == "if d_state3==1"){
			local coltag = "MS Only"
		}
		else if ("`cond'" == "if d_state4==1"){
			local coltag = "TX Only"
		}

		* Weighted
		reg `Y' treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote Z_* `cond' [aweight=ipw]
		local lci_noun = _b[treat_noun] - invttail( e(df_r), 0.025 )*_se[treat_noun]
		local uci_noun = _b[treat_noun] + invttail( e(df_r), 0.025 )*_se[treat_noun]
		local pval = 2*ttail(e(df_r),abs( _b[treat_noun]/_se[treat_noun] ))
		qui sum `Y' [aweight=ipw] if treat_noun == 0 & e(sample)
		local c_mean = r(mean)
		local c_se = r(sd) / sqrt(r(N))
		local c_N = r(N)
		qui sum `Y' [aweight=ipw] if treat_noun == 1 & e(sample)
		local t_N = r(N)
		local ipw = "Y"

		if ("`cond'" == "") {
		outreg2 using "TableA6_Robustness_KYandLAonly.tex", ctitle("`coltag'") se bracket rdec(3) label tex(frag) ///
			keep(treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
			addstat("Verb Group Mean Outcome", `c_mean') ///
			addtext("State-By-Covariate Interactions?", Y, "Weighted?", Y) replace
		}
		else {
		outreg2 using "TableA6_Robustness_KYandLAonly.tex", ctitle("`coltag'") se bracket rdec(2) label tex(frag) ///
			keep(treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
			addstat("Verb Group Mean Outcome", `c_mean') ///
			addtext("State-By-Covariate Interactions?", Y, "Weighted?", Y) append
		}

		* Unweighted
		reg `Y' treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote Z_* `cond'
		local lci_noun = _b[treat_noun] - invttail( e(df_r), 0.025 )*_se[treat_noun]
		local uci_noun = _b[treat_noun] + invttail( e(df_r), 0.025 )*_se[treat_noun]
		local pval = 2*ttail(e(df_r),abs( _b[treat_noun]/_se[treat_noun] ))
		qui sum `Y' if treat_noun == 0 & e(sample)
		local c_mean = r(mean)
		local c_se = r(sd) / sqrt(r(N))
		local c_N = r(N)
		qui sum `Y' if treat_noun == 1 & e(sample)
		local t_N = r(N)
		local ipw = "N"

		outreg2 using "TableA6_Robustness_KYandLAonly.tex", ctitle("`coltag'") se bracket rdec(2) label tex(frag) ///
			keep(treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
			addstat("Verb Group Mean Outcome", `c_mean') ///
			addtext("State-By-Covariate Interactions?", Y, "Weighted?", N) append
			
	}
}

/*------------------------------------------------------------------------------
 Table A7: Robustness Check - Subjects in KY, LA only AND
								Entering Exp On/Day Before Elec Day
------------------------------------------------------------------------------*/

* Re-load data
use PublicReplicationData.dta, clear

* Keep only subjects who entered study on or day before election and are in KY, LA only
keep if inlist(state, "KY", "LA") & inlist(daysbefore, 0, 1)

* Drop IPW variable 
drop ipw 

* Recalculate IPWs

foreach s in 0 1 {
	preserve
	contract treat if ssi==`s', freq(freq) percent(pct)
	list, t noobs clean
	gen ipw`s' = 1/(pct/100)
	list, t noobs clean
	keep treat ipw`s'
	gen ssi = `s'
	save "temp_ipw_`s'.dta", replace
	restore	
}

merge m:1 ssi treat using "temp_ipw_0.dta"
tab treat ipw0 if ssi==0, m
tab treat ipw0 if ssi==1, m
drop _merge
erase "temp_ipw_0.dta"

merge m:1 ssi treat using "temp_ipw_1.dta"
tab treat ipw1 if ssi==0, m
tab treat ipw1 if ssi==1, m
drop _merge
erase "temp_ipw_1.dta"

gen ipw = ipw1
replace ipw = ipw0 if ssi==0
tab ssi ipw, m
drop ipw1 ipw0

* Create state-by-covariate interactions
foreach st in 2 3 4 {
	foreach v in d_date2 d_date3 d_date4 d_date5 d_date6 d_date7 d_date8 d_gend2 d_gend3 d_race1 d_race2 d_race3 daysbefore V_G04 V_G06 V_G08 V_G10 V_G12 V_G14 V_P04 V_P06 V_P08 V_P10 V_P12 V_P14 V_P15 V_PP04 V_PP08 V_PP12 {
		gen Z_dstate`st'_`v' = d_state`st' * `v' 
		qui sum Z_dstate`st'_`v'
		if (r(sd) == 0 | r(sd) == .) {
		drop Z_dstate`st'_`v'
		}
	}
}

* Estimate models
foreach Y in V15 {
	foreach cond in "" "if ssi==0" "if ssi==1" {

		* Make column labels
		if ("`cond'" == ""){
			local coltag = "Entire Sample"
		}
		else if ("`cond'" == "if ssi==0"){
			local coltag = "YouGov Only"
		}
		else if ("`cond'" == "if ssi==1"){
			local coltag = "SSI Only"
		}
		else if ("`cond'" == "if d_state1==1"){
			local coltag = "KY Only"
		}
		else if ("`cond'" == "if d_state2==1"){
			local coltag = "LA Only"
		}
		else if ("`cond'" == "if d_state3==1"){
			local coltag = "MS Only"
		}
		else if ("`cond'" == "if d_state4==1"){
			local coltag = "TX Only"
		}

		* Weighted
		reg `Y' treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote Z_* `cond' [aweight=ipw]
		local lci_noun = _b[treat_noun] - invttail( e(df_r), 0.025 )*_se[treat_noun]
		local uci_noun = _b[treat_noun] + invttail( e(df_r), 0.025 )*_se[treat_noun]
		local pval = 2*ttail(e(df_r),abs( _b[treat_noun]/_se[treat_noun] ))
		qui sum `Y' [aweight=ipw] if treat_noun == 0 & e(sample)
		local c_mean = r(mean)
		local c_se = r(sd) / sqrt(r(N))
		local c_N = r(N)
		qui sum `Y' [aweight=ipw] if treat_noun == 1 & e(sample)
		local t_N = r(N)
		local ipw = "Y"

		if ("`cond'" == "") {
		outreg2 using "TableA7_Robustness_OnBeforeED_KYandLAonly.tex", ctitle("`coltag'") se bracket rdec(3) label tex(frag) ///
			keep(treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
			addstat("Verb Group Mean Outcome", `c_mean') ///
			addtext("State-By-Covariate Interactions?", Y, "Weighted?", Y) replace
		}
		else {
		outreg2 using "TableA7_Robustness_OnBeforeED_KYandLAonly.tex", ctitle("`coltag'") se bracket rdec(2) label tex(frag) ///
			keep(treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
			addstat("Verb Group Mean Outcome", `c_mean') ///
			addtext("State-By-Covariate Interactions?", Y, "Weighted?", Y) append
		}

		* Unweighted
		reg `Y' treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote Z_* `cond'
		local lci_noun = _b[treat_noun] - invttail( e(df_r), 0.025 )*_se[treat_noun]
		local uci_noun = _b[treat_noun] + invttail( e(df_r), 0.025 )*_se[treat_noun]
		local pval = 2*ttail(e(df_r),abs( _b[treat_noun]/_se[treat_noun] ))
		qui sum `Y' if treat_noun == 0 & e(sample)
		local c_mean = r(mean)
		local c_se = r(sd) / sqrt(r(N))
		local c_N = r(N)
		qui sum `Y' if treat_noun == 1 & e(sample)
		local t_N = r(N)
		local ipw = "N"

		outreg2 using "TableA7_Robustness_OnBeforeED_KYandLAonly.tex", ctitle("`coltag'") se bracket rdec(2) label tex(frag) ///
			keep(treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
			addstat("Verb Group Mean Outcome", `c_mean') ///
			addtext("State-By-Covariate Interactions?", Y, "Weighted?", N) append
			
	}
}


/*------------------------------------------------------------------------------
 Table A8: Robustness Check - Subjects Viewed/Responded to All 10 Questions
------------------------------------------------------------------------------*/

* Re-load data
use PublicReplicationData.dta, clear

* Keep only subjects who completed all 10 items in the survey block to which they're assigned
tab nmiss, m
keep if nmiss == 0

* Drop IPW variable 
drop ipw 

* Recalculate IPWs
foreach s in 0 1 {
	preserve
	contract treat if ssi==`s', freq(freq) percent(pct)
	list, t noobs clean
	gen ipw`s' = 1/(pct/100)
	list, t noobs clean
	keep treat ipw`s'
	gen ssi = `s'
	save "temp_ipw_`s'.dta", replace
	restore	
}

merge m:1 ssi treat using "temp_ipw_0.dta"
tab treat ipw0 if ssi==0, m
tab treat ipw0 if ssi==1, m
drop _merge
erase "temp_ipw_0.dta"

merge m:1 ssi treat using "temp_ipw_1.dta"
tab treat ipw1 if ssi==0, m
tab treat ipw1 if ssi==1, m
drop _merge
erase "temp_ipw_1.dta"

gen ipw = ipw1
replace ipw = ipw0 if ssi==0
tab ssi ipw, m
drop ipw1 ipw0

* Create state-by-covariate interactions
foreach st in 2 3 4 {
	foreach v in d_date2 d_date3 d_date4 d_date5 d_date6 d_date7 d_date8 d_gend2 d_gend3 d_race1 d_race2 d_race3 daysbefore V_G04 V_G06 V_G08 V_G10 V_G12 V_G14 V_P04 V_P06 V_P08 V_P10 V_P12 V_P14 V_P15 V_PP04 V_PP08 V_PP12 {
		gen Z_dstate`st'_`v' = d_state`st' * `v' 
		qui sum Z_dstate`st'_`v'
		if (r(sd) == 0 | r(sd) == .) {
			drop Z_dstate`st'_`v'
		}
	}
}

* Estimate models
foreach Y in V15 {
	foreach cond in "" "if ssi==0" "if ssi==1" "if d_state1==1" "if d_state2==1" "if d_state3==1" "if d_state4==1" {

		* Make column labels
		if ("`cond'" == ""){
			local coltag = "Entire Sample"
		}
		else if ("`cond'" == "if ssi==0"){
			local coltag = "YouGov Only"
		}
		else if ("`cond'" == "if ssi==1"){
			local coltag = "SSI Only"
		}
		else if ("`cond'" == "if d_state1==1"){
			local coltag = "KY Only"
		}
		else if ("`cond'" == "if d_state2==1"){
			local coltag = "LA Only"
		}
		else if ("`cond'" == "if d_state3==1"){
			local coltag = "MS Only"
		}
		else if ("`cond'" == "if d_state4==1"){
			local coltag = "TX Only"
		}

		* Weighted
		reg `Y' treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote Z_* `cond' [aweight=ipw]
		local lci_noun = _b[treat_noun] - invttail( e(df_r), 0.025 )*_se[treat_noun]
		local uci_noun = _b[treat_noun] + invttail( e(df_r), 0.025 )*_se[treat_noun]
		local pval = 2*ttail(e(df_r),abs( _b[treat_noun]/_se[treat_noun] ))
		qui sum `Y' [aweight=ipw] if treat_noun == 0 & e(sample)
		local c_mean = r(mean)
		local c_se = r(sd) / sqrt(r(N))
		local c_N = r(N)
		qui sum `Y' [aweight=ipw] if treat_noun == 1 & e(sample)
		local t_N = r(N)
		local ipw = "Y"

		if ("`cond'" == "") {
		outreg2 using "TableA8_Robustness_Answered10Q.tex", ctitle("`coltag'") se bracket rdec(3) label tex(frag) ///
			keep(treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
			addstat("Verb Group Mean Outcome", `c_mean') ///
			addtext("State-By-Covariate Interactions?", Y, "Weighted?", Y) replace
		}
		else {
		outreg2 using "TableA8_Robustness_Answered10Q.tex", ctitle("`coltag'") se bracket rdec(2) label tex(frag) ///
			keep(treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
			addstat("Verb Group Mean Outcome", `c_mean') ///
			addtext("State-By-Covariate Interactions?", Y, "Weighted?", Y) append
		}

		* Unweighted
		reg `Y' treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote Z_* `cond'
		local lci_noun = _b[treat_noun] - invttail( e(df_r), 0.025 )*_se[treat_noun]
		local uci_noun = _b[treat_noun] + invttail( e(df_r), 0.025 )*_se[treat_noun]
		local pval = 2*ttail(e(df_r),abs( _b[treat_noun]/_se[treat_noun] ))
		qui sum `Y' if treat_noun == 0 & e(sample)
		local c_mean = r(mean)
		local c_se = r(sd) / sqrt(r(N))
		local c_N = r(N)
		qui sum `Y' if treat_noun == 1 & e(sample)
		local t_N = r(N)
		local ipw = "N"

		outreg2 using "TableA8_Robustness_Answered10Q.tex", ctitle("`coltag'") se bracket rdec(2) label tex(frag) ///
			keep(treat_noun ssi d_state2-d_state4 d_date2-d_date8 d_gend2-d_gend3 d_race1-d_race3 daysbefore $pastvote) ///
			addstat("Verb Group Mean Outcome", `c_mean') ///
			addtext("State-By-Covariate Interactions?", Y, "Weighted?", N) append
			
	}
}

/*------------------------------------------------------------------------------
 Appendix E - Regression reported in #2 (Appendix page A-26)
	See AppendixE.R
	Note: 95% confidence intervals from this analysis are used in Figure 1
------------------------------------------------------------------------------*/

log close
