## ========================================================================== ##
## Public Replication File for:
##   
##   Alan S. Gerber, Gregory A. Huber, and Albert H. Fang
## 
## "Do Subtle Linguistic Interventions Priming a Social Identity
## as a Voter Have Outsized Effets on Voter Turnout? Evidence
## From a New Replication Experiment"
## 
## Political Psychology. doi: 10.1111/pops.12446
## 
## Last updated: 26 September 2017
##
## -------------------------------------------------------------------------- ##
##
## PROGRAM DESCRIPTION:
## This program creates Figure 1
##
## ========================================================================== ##

rm(list=ls(all=TRUE))

# Install packages if not yet installed; load packages
pkgs <- c("ggplot2", "plyr")
for(i in 1:length(pkgs)){
  if ( pkgs[i] %in% rownames(installed.packages()) == FALSE ) {
    install.packages(pkgs[i], dependencies=TRUE)
  } else {
    cat("Package ", pkgs[i], " already installed\n")
  }
}
library(ggplot2); library(plyr)

# Read in estimation results
est <- read.csv("Table3_RegressionEstimates.csv",
                header=TRUE, stringsAsFactors=FALSE, strip.white=TRUE)

dif <- read.csv("Table3_DifferenceInProportions.csv",
                header=TRUE, stringsAsFactors=FALSE, strip.white=TRUE)

# Define functions to pre-process data frames
describeSample <- function(d) {
  d$sample <- ifelse(d$sample == "",               "Entire\nSample", d$sample)
  d$sample <- ifelse(d$sample == "if ssi==0",      "YouGov Only\nSubsample", d$sample)
  d$sample <- ifelse(d$sample == "if ssi==1",      "SSI Only\nSubsample", d$sample)
  d$sample <- ifelse(d$sample == "if d_state1==1", "KY Only\nSubsample", d$sample)
  d$sample <- ifelse(d$sample == "if d_state2==1", "LA Only\nSubsample", d$sample)
  d$sample <- ifelse(d$sample == "if d_state3==1", "MS Only\nSubsample", d$sample)
  d$sample <- ifelse(d$sample == "if d_state4==1", "TX Only\nSubsample", d$sample)
  d$sample <- factor(d$sample, levels=c("Entire\nSample",
                                        "SSI Only\nSubsample",
                                        "YouGov Only\nSubsample",
                                        "KY Only\nSubsample",
                                        "LA Only\nSubsample",
                                        "MS Only\nSubsample",
                                        "TX Only\nSubsample"))
  return(d)
}

describeDV <- function(d, vars, varlabs) {
  d$Outcome <- rep(NA, nrow(d))
  for(i in 1:length(vars)){
    d$Outcome <- ifelse(d$dv == vars[i], varlabs[i], d$Outcome)
  }
  return(d)
}

# Pre-process data frames
est <- describeSample(est)
dif <- describeSample(dif)

vars <- names(table(est$dv))
varlabs <- c("Voted in 2015 General Election")

est <- describeDV(d=est, vars=vars, varlabs=varlabs)
dif <- describeDV(d=dif, vars=vars, varlabs=varlabs)

# Prepare data for plotting - this experiment
est_vote <- est[est$dv=="V15" & est$ipw == "Y",]
est_vote$study <- "DV: Turnout in 2015 General Election\n(this field experiment)"
est_vote$n <- est_vote$c_N + est_vote$t_N

# Prepare data for plotting - Bryan et al. 2011
bryanetal2011 <- data.frame(study = "DV: Turnout in 2008 Presidential or 2009 Gubernatorial Election\nBryan et al. (2011)",
                            dv = "Vote",
                            sample = c("California\n2008 Presidential\nElection\n(Study 2)", "New Jersey\n2009 Gubernatorial\nElection\n(Study 3)"),
                            ipw = "N",
                            b_noun = c(.137, .109),
                            se_noun = c(.0668474, .0492075),
                            lci_noun = c( .0034754,  .0060128),
                            uci_noun = c(.2692519,   .1995947),
                            p_noun = c(.044, 0.037),
                            n = c(88, 214))
bryanetal2011

# Prepare data for plotting - Gerber et al. 2016
sample_labels<-c("Entire\nSample", "MI Only", "MO Only", "TN Only", "No\nCompetitive\nHouse\nPrimary",
                 "Either\nHouse\nPrimary\nCompetitive", "Ever\nVoters", "Have\nVoted in\nPrimary", "Have\nVoted\nbut\nNever\nin Primary",
                 "No Prior\nHistory\nof Voting", "Predicted\nTurnout\n>70%")
gerberetal2016 <- data.frame(study = "DV: Turnout in 2014 Primary Election\nGerber et al. (2016)",
                             dv = "V14",
                             sample = sample_labels,
                             ipw = "N",
                             b_noun = c(-.004, -.007, -.005, 0, -.011, .004, -.004, -.014, .003, -.003, -.007),
                             se_noun = c(.011, .015, .023, .021, .015, .016, .012, .021, .013, .018, .027),
                             lci_noun = c(-.0256291,-.036301 , -.0508369,  -.0405925 , -.0406788 ,  -.0272042 , -.0275932  , -.0549652  , -.0227793 , -.0388927 , -.0595525),
                             uci_noun = c(.0170544,.0224731, .041209,  .0415531 ,   .0178146 ,  .0352434 , .0185943 ,    .0278704,  .0297683,  .0329195,  .0461267  ),
                             n = c(2236+2232, 1041+1015, 577+563, 618+654, 1307+1305, 929+927, 2047+2033, 848+832, 1199+1201, 189+199, 377+407))

gerberetal2016$sample <- factor(gerberetal2016$sample,
                                levels=sample_labels)

# Stack data frames together 
est_vote <- rbind.fill(bryanetal2011,
                       gerberetal2016,
                       est_vote)
est_vote

# Create Figure 1
est_vote$study <- factor(est_vote$study, levels=c("DV: Turnout in 2015 General Election\n(this field experiment)" ,
                                                  "DV: Turnout in 2014 Primary Election\nGerber et al. (2016)",
                                                  "DV: Turnout in 2008 Presidential or 2009 Gubernatorial Election\nBryan et al. (2011)"))

ggplot(est_vote, aes(x=sample, y=b_noun)) +
  geom_errorbar(aes(ymin=lci_noun, ymax=uci_noun), lwd=1, width=1/8) +
  geom_point(size=4, pch=16) +
  geom_hline(yintercept=0, lty=2, lwd=1, colour="grey50") +
  xlab("\nSample Definition") + ylab("Estimated Effect of Noun Wording on Turnout Rate (as compared to verb wording)\n") +
  scale_y_continuous(limits=c(-.3, .3), breaks=seq(-.4, .4, .1)) +
  geom_text(data=est_vote, aes(x=sample, y=-.3, label=paste0("italic('n')==",n)), size=3.5, parse=TRUE) +
  theme_bw(base_size=15) + facet_wrap(~study, scales="free", ncol=1) +
  theme(axis.text.x = element_text(size=8),
        axis.text.y = element_text(size=10),
        axis.title = element_text(size=11, face="bold")) 

# Save file
ggsave("Figure1.pdf", width=9, height=10.5)
